linux-next: manual merge of the mm-stable tree with the kspp tree

From: Stephen Rothwell
Date: Tue Oct 04 2022 - 05:44:03 EST


Hi all,

Today's linux-next merge of the mm-stable tree got a conflict in:

include/linux/fortify-string.h

between commit:

9f7d69c5cd23 ("fortify: Convert to struct vs member helpers")

from the kspp tree and commit:

ff901d80fff6 ("x86: kmsan: use __msan_ string functions where possible.")

from the mm-stable tree.

I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.

--
Cheers,
Stephen Rothwell

diff --cc include/linux/fortify-string.h
index b62c90cfafaf,6c8a1a29d0b6..000000000000
--- a/include/linux/fortify-string.h
+++ b/include/linux/fortify-string.h
@@@ -325,11 -282,13 +325,13 @@@ __FORTIFY_INLINE void fortify_memset_ch
})

/*
* __builtin_object_size() must be captured here to avoid evaluating argument
* side-effects further into the macro layers.
*/
+ #ifndef CONFIG_KMSAN
#define memset(p, c, s) __fortify_memset_chk(p, c, s, \
- __builtin_object_size(p, 0), __builtin_object_size(p, 1))
+ __struct_size(p), __member_size(p))
+ #endif

/*
* To make sure the compiler can enforce protection against buffer overflows,
@@@ -325,11 -282,13 +325,13 @@@ __FORTIFY_INLINE void fortify_memset_ch

/*
- * __builtin_object_size() must be captured here to avoid evaluating argument
- * side-effects further into the macro layers.
+ * __struct_size() vs __member_size() must be captured here to avoid
+ * evaluating argument side-effects further into the macro layers.
*/

Attachment: pgpx50U4vZ0Az.pgp
Description: OpenPGP digital signature